%Vergleichsbertragungsfunktionen 
%filter_bin_bessel_butter.m
%Eingangsgre Sprungfunktion

clear, clf, clc, format long
nmin = 1; nmax = 8; f = zeros(1,nmax+1); delta_t = 0.001;

disp ('G_BINOMIAL-Filter')
for n=nmin:nmax
    for i=0:n
    f(i+1)=factorial(n) / (factorial(i)*factorial(n-i));
    end
    G_BINOM(n) = tf(1, f(1:n+1));
end
tmax = 20; t = 0:delta_t:tmax; w = ones(length(t),1);
figure (1)
for n = nmin:nmax
        x = step(G_BINOM(n), t);
        plot(t, x), axis ([0 tmax 0  1.05])
        hold on, grid on
end
plot(t, w, 'k')
title('Sprungantwort von Binomial-Vergleichsbertragungsfunktionen')
xlabel('Normierte Zeit \omega_k * t')
ylabel('Sprungantwort x(t)')

disp ('G_BESSEL-Filter')
for n=nmin:nmax
    for i=0:n
    f(n+1-i)=factorial(2*n-i)/(2^(n-i)*factorial(i)*factorial(n-i));
    end
    G_BESSEL(n) = tf(f(n+1), f(1:n+1));
end
tmax = 3.5; t = 0:delta_t:tmax; w = ones(length(t),1);
figure (2)
for n = nmin:nmax
        x = step(G_BESSEL(n), t);
        ue = max(x) - 1.0;
        if ue < 0.0
            ue = 0.0;
        end
        n, ue
        k = 1;
        while x(k) < 1.0 && k < length(x)
           k = k + 1;
        end
        if ue == 0.0
           tanr = inf
        else
           tanr = t(k)
        end
        plot(t, x), axis ([0 tmax 0  1.05])
        hold on, grid on
end
plot(t, w, 'k')
title('Sprungantwort von BESSEL-Vergleichsbertragungsfunktionen')
xlabel('Normierte Zeit \omega_k * t')
ylabel('Sprungantwort x(t)')

disp ('G_BUTTERWORTH-Filter')
for n=nmin:nmax
    if mod(n, 2) == 1
        f = [1.0 1.0];
        for i=1:(n-1)/2
        f = conv (f, [1.0 -2.0*cos((2*i+n-1)*pi/(2*n)) 1.0]);
        end
    else
        f = 1.0;
        for i=1:n/2
        f = conv (f, [1.0 -2.0*cos((2*i+n-1)*pi/(2*n)) 1.0]);
        end
     end
% n, f
G_BUTTER(n) = tf(1, f(1:n+1));
end
tmax = 25; t = 0:delta_t:tmax; w = ones(length(t),1);
figure (3)
for n = nmin:nmax
        x = step(G_BUTTER(n), t);
        ue = max(x) - 1.0;
        if ue < 0.0
            ue = 0.0
        end
        n, ue
        k = 1;
        while x(k) < 1.0 && k < length(x)
           k = k + 1;
        end
        if ue == 0.0
           tanr = inf
        else
           tanr = t(k)
        end
        plot(t, x), axis ([0 tmax 0  1.20])
        hold on, grid on
end
plot(t, w, 'k')
title('Sprungantwort von BUTTERWORTH-Vergleichsbertragungsfunktionen')
xlabel('Normierte Zeit \omega_k * t')
ylabel('Sprungantwort x(t)')


disp ('G_BINOMIAL-Filter'),    G_BINOM
disp ('G_BESSEL-Filter'),      G_BESSEL
disp ('G_BUTTERWORTH-Filter'), G_BUTTER

figure(4)
for n = nmin:nmax
    bodemag(G_BINOM(n))
    hold on, grid on
end
figure(5)
for n = nmin:nmax
    bodemag(G_BESSEL(n))
    hold on, grid on
end
figure(6)
for n = nmin:nmax
    bodemag(G_BUTTER(n))
    hold on, grid on
end

%{
Ergebnisse
G_BINOMIAL-Filter
G_BESSEL-Filter

n =     1
ue =    0
tanr =  Inf
n =     2
ue =    0.004213189866210
tanr =  3.023000000000000
n =     3
ue =    0.007537464498866
tanr =  2.301000000000000
n =     4
ue =    0.008354195336015
tanr =  2.007000000000000
n =     5
ue =    0.007726830486380
tanr =  1.849000000000000
n =     6
ue =    0.006418390918602
tanr =  1.753000000000000
n =     7
ue =    0.004900309446955
tanr =  1.691000000000000
n =     8
ue =    0.003439397479059
tanr =  1.649000000000000

G_BUTTERWORTH-Filter
n =     1
ue =    0
tanr =  Inf
n =     2
ue =    0.043213917967628
tanr =  3.333000000000000
n =     3
ue =    0.081465439365870
tanr =  3.780000000000000
n =     4
ue =    0.108301506155886
tanr =  4.402000000000000
n =     5
ue =    0.127770466207265
tanr =  5.065000000000000
n =     6
ue =    0.142513533983500
tanr =  5.742000000000000
n =     7
ue =    0.154087707479158
tanr =  6.423000000000000
n =     8
ue =    0.163440580407651
tanr =  7.105000000000000

G_BINOMIAL-Filter
Transfer function from input 1 to output:
  1
-----
s + 1
Transfer function from input 2 to output:
      1
-------------
s^2 + 2 s + 1
Transfer function from input 3 to output:
          1
---------------------
s^3 + 3 s^2 + 3 s + 1
Transfer function from input 4 to output:
              1
-----------------------------
s^4 + 4 s^3 + 6 s^2 + 4 s + 1
Transfer function from input 5 to output:
                   1
---------------------------------------
s^5 + 5 s^4 + 10 s^3 + 10 s^2 + 5 s + 1
Transfer function from input 6 to output:
                       1
------------------------------------------------
s^6 + 6 s^5 + 15 s^4 + 20 s^3 + 15 s^2 + 6 s + 1
Transfer function from input 7 to output:
                            1
---------------------------------------------------------
s^7 + 7 s^6 + 21 s^5 + 35 s^4 + 35 s^3 + 21 s^2 + 7 s + 1
Transfer function from input 8 to output:
                                1
------------------------------------------------------------------
s^8 + 8 s^7 + 28 s^6 + 56 s^5 + 70 s^4 + 56 s^3 + 28 s^2 + 8 s + 1
 

G_BESSEL-Filter
Transfer function from input 1 to output:
  1
-----
s + 1
Transfer function from input 2 to output:
      3
-------------
s^2 + 3 s + 3
Transfer function from input 3 to output:
          15
-----------------------
s^3 + 6 s^2 + 15 s + 15
Transfer function from input 4 to output:
                105
-----------------------------------
s^4 + 10 s^3 + 45 s^2 + 105 s + 105
Transfer function from input 5 to output:
                     945
----------------------------------------------
s^5 + 15 s^4 + 105 s^3 + 420 s^2 + 945 s + 945
Transfer function from input 6 to output:
                            10395
--------------------------------------------------------------
s^6 + 21 s^5 + 210 s^4 + 1260 s^3 + 4725 s^2 + 10395 s + 10395
Transfer function from input 7 to output:
                                   135135
-----------------------------------------------------------------------------
s^7 + 28 s^6 + 378 s^5 + 3150 s^4 + 17325 s^3 + 62370 s^2 + 135135 s + 135135
Transfer function from input 8 to output:
                                            2.027e006
-------------------------------------------------------------------------------------------------
s^8 + 36 s^7 + 630 s^6 + 6930 s^5 + 51975 s^4 + 270270 s^3 + 945945 s^2 + 2.027e006 s + 2.027e006


G_BUTTERWORTH-Filter
Transfer function from input 1 to output:
  1
-----
s + 1
Transfer function from input 2 to output:
        1
-----------------
s^2 + 1.414 s + 1
Transfer function from input 3 to output:
          1
---------------------
s^3 + 2 s^2 + 2 s + 1
Transfer function from input 4 to output:
                    1
-----------------------------------------
s^4 + 2.613 s^3 + 3.414 s^2 + 2.613 s + 1
Transfer function from input 5 to output:
                          1
-----------------------------------------------------
s^5 + 3.236 s^4 + 5.236 s^3 + 5.236 s^2 + 3.236 s + 1
Transfer function from input 6 to output:
                                1
-----------------------------------------------------------------
s^6 + 3.864 s^5 + 7.464 s^4 + 9.142 s^3 + 7.464 s^2 + 3.864 s + 1
Transfer function from input 7 to output:
                                     1
---------------------------------------------------------------------------
s^7 + 4.494 s^6 + 10.1 s^5 + 14.59 s^4 + 14.59 s^3 + 10.1 s^2 + 4.494 s + 1
Transfer function from input 8 to output:
                                            1
-----------------------------------------------------------------------------------------
s^8 + 5.126 s^7 + 13.14 s^6 + 21.85 s^5 + 25.69 s^4 + 21.85 s^3 + 13.14 s^2 + 5.126 s + 1

%}
