%m_beispiel_10_2_2_m.m
%Optimierung im Zeitbereich
%IAE-, ITAE-, ISTAE-Kriterium

clc, clear, clf

tmax = 25.0;
%Regelstrecke
KS = 2; TS1 = 12; TS2 = 4; TS3 = 2;
%Multiplikativer Regler fr Kompensation
TNm = TS1; TVm = TS2; T1 = 1e-4;

%IAE-Kriterium, n = 2
n = 2, f1 = 1.32475;
KRm_IAE = TNm / (f1^2 * KS * TS3)
omk = 1.0 / (f1 * TS3)

%ITAE-Kriterium, n = 2
n = 2, f1 = 1.50488;
KRm_ITAE = TNm / (f1^2 * KS * TS3)
omk = 1.0 / (f1 * TS3)

%ISTAE-Kriterium, n = 2
n = 2, f1 = 1.62763;
KRm_ISTAE = TNm / (f1^2 * KS * TS3)
omk = 1.0 / (f1 * TS3)

%IAE-Kriterium, n = 4
n = 4, f1 = 2.4527; f2 = 3.1788; f3 = 1.5703;
KRa_IAE = (500.0*f1 - 9.0*f3^3) / (18.0 * f3^3)
TNa = (1500.0*f1*f3 - 27.0*f3^4) / 1250.0
TVa = (600.0*f2*f3 - 162.0*f3^3) / (500.0*f1 - 9.0*f3^3)
omk = 5.0 / (6.0*f3)
a0_IAE = KRa_IAE*KS / (TNa*TS1*TS2*TS3)
a1_IAE = a0_IAE*TNa
a2_IAE = a0_IAE*TNa*TVa

%ITAE-Kriterium, n = 4
n = 4, f1 = 2.6473; f2 = 3.3458; f3 = 1.9521;
KRa_ITAE = (500.0*f1 - 9.0*f3^3) / (18.0 * f3^3)
TNa1 = (1500.0*f1*f3 - 27.0*f3^4) / 1250.0
TVa1 = (600.0*f2*f3 - 162.0*f3^3) / (500.0*f1 - 9.0*f3^3)
omk1 = 5.0 / (6.0*f3)
a0_ITAE = KRa_ITAE*KS / (TNa1*TS1*TS2*TS3)
a1_ITAE = a0_ITAE*TNa1
a2_ITAE = a0_ITAE*TNa1*TVa1

%ISTAE-Kriterium, n = 4
n = 4, f1 = 2.8071; f2 = 3.5673; f3 = 2.2746;
KRa_ISTAE = (500.0*f1 - 9.0*f3^3) / (18.0 * f3^3)
TNa2 = (1500.0*f1*f3 - 27.0*f3^4) / 1250.0
TVa2 = (600.0*f2*f3 - 162.0*f3^3) / (500.0*f1 - 9.0*f3^3)
omk2 = 5.0 / (6.0*f3)
a0_ISTAE = KRa_ISTAE*KS / (TNa2*TS1*TS2*TS3)
a1_ISTAE = a0_ISTAE*TNa2
a2_ISTAE = a0_ISTAE*TNa2*TVa2

sim('m_beispiel_10_2_2')

lw = 1.5;
subplot(121)
plot (x.time, x.signals.values(:,1),'k-', 'LineWidth', lw)
grid on, hold on,
plot (x.time, x.signals.values(:,2),'k:' , 'LineWidth', 1.5*lw)
plot (x.time, x.signals.values(:,3),'k--', 'LineWidth', lw)
title ('Optimierung im Zeitbereich, Betragskriterien')
xlabel('Zeit t / s'), ylabel('Sprungantwort x(t)'), axis([0 tmax 0 1.10]),
h = legend(' IAE,     n = 2',' ITAE,   n = 2',' ISTAE, n = 2');
hold off

subplot (122)
plot (x.time, x.signals.values(:,4),'k-', 'LineWidth', lw)
grid on, hold on,
plot (x.time, x.signals.values(:,5),'k:', 'LineWidth', lw)
plot (x.time, x.signals.values(:,6),'k--', 'LineWidth', lw)
title ('IAE-, ITAE-, ISTAE-Kriterium')
xlabel('Zeit t / s'), ylabel('Sprungantwort x(t)'), axis([0 tmax 0 1.10]),
h = legend(' IAE,     n = 4',' ITAE,   n = 4',' ISTAE, n = 4');
hold off
format long
x_max = max(x.signals.values(:,:))
for i = 1:6
    k = 1;
    while x.signals.values(k,i) < 1.0
        k = k + 1;
        end
    i, tanr = x.time(k),
end

%{ 
Ergebnisse
n = 2, KRm_IAE =  1.7094, omk =  0.3774

n = 2, KRm_ITAE = 1.3247, omk =  0.3323

n = 2, KRm_ISTAE = 1.1324, omk =  0.3072

n = 4, KRa_IAE = 17.0952, TNa =  4.4904, TVa =  1.9872, omk =  0.5307
a0_IAE =  0.0793, a1_IAE =  0.3561, a2_IAE =  0.7077

n = 4, KRa_ITAE = 9.3854, TNa1 =  5.8877, TVa1 =  2.1594, omk1 =  0.4269
a0_ITAE =  0.0332, a1_ITAE =  0.1955, a2_ITAE =  0.4222

n = 4, KRa_ISTAE =  6.1258, TNa2 =  7.0838, TVa2 =  2.2826, omk2 =  0.3664
a0_ISTAE =  0.0180, a1_ISTAE =  0.1276, a2_ISTAE =  0.2913

x_max = [1.0623 1.0277 1.0123 1.0468 1.0185 1.0097]

i =   1, tanr =  8.1140
i =   2, tanr = 11.0670
i =   3, tanr = 14.1190

i =   4, tanr =  7.9400
i =   5, tanr = 10.9270
i =   6, tanr = 14.0750
      
%}     