%MATLAB Script-File zupt2_168.m
%Zustandsregelung einer PT2-Strecke
KS=1; w0S=1; DS=0.707;            %Streckenparameter
numGS=KS*w0S^2;                   %Zhlerpolynom der Strecke
denGS=[1 2*DS*w0S w0S^2];         %Nennerpolynom der Strecke
sys=ss(tf(numGS,denGS));          %GS(s) --> Zustandsmodell
[sysR,TR]=T_RNFORM_168(sys);  	  %Zustandsmodell in 
%Regelungsnormalform mit Function-File T_RNFORM_1.m

clf
subplot(121)                      %Teilbild links
hold on
grid on
text(.1,1.07,'{\it4*}{\it\omega}_{0S}') %Bezeichnung der Kurve
text(2.,1.07,'{\it2*}{\it\omega}_{0S}')
text(5,1.07,'{\it\omega}_{0S}')

for k=[1 2 4]
  w0Z=k*w0S;                      %w0 der Zustandsregelung
  sp1Z=w0Z*(-DS+j*sqrt(1-DS^2));  %Pole der
  sp2Z=w0Z*(-DS-j*sqrt(1-DS^2));  %Zustandsregelung
  poleZ=[sp1Z,sp2Z];              %Zeilenvektor der Vorgabepole
  AR=sysR.a;					  %Systemmatrix von sysR
  bR=sysR.b;					  %Eingangsvektor von sysR
  rR=acker(AR,bR,poleZ);          %Rckfhrkoeffizienten
  rR=-rR;                         %sind positiv
  vwR=(w0S^2-rR(1))/(KS*w0S^2);   %Vorfilter
  AS=AR+bR*rR;                    %Systemmatrix der Zustandsreg.
  bS=vwR*bR;                      %Eingangsvektor d. ZR.
  cR=sysR.c;					  %Ausgangsvektor von sysR
  dR=sysR.d;					  %Durchgangsfaktor von sysR
  step(AS,bS,cR,dR) 			  %Sprungantwort   
  grid                            %kartesische Gitterlinien 
end
subplot(122),                     %rechtes Teilbild
pzmap([sp1Z,sp2Z],[])             %Pol-Nullstellenplan
axis([-4,0,-4,4])                 %Skalierung
sgrid([0:0.1:1],[0:0.4:4])        %Gitterlinien fr D, w0
axis('equal')                     %gleicher Skalierungsfaktor
